@@ -46,7 +46,8 @@ This is a multi-part message in MIME format.
 --{boundary}
 Content-Type: text/plain
 
-Delivery failed.
+Delivery failed for:
+- {recipients}
 
 Destination host responded:
 {code} {message}
@@ -58,7 +59,7 @@ Remote-MTA: dns; {client_name} [{client_ip}]
 Diagnostic-Code: {protocol}; {code} {message}
 
 --{boundary}
-Content-Type: message/rfc822
+Content-Type: {content_type}
 
 """)
 # }}}
@@ -94,6 +95,8 @@ class Bounce(Envelope):
     #:
     #: * ``boundary`` -- A randomly generated MIME boundary string.
     #: * ``sender`` -- The sender of the original message.
+    #: * ``recipients`` -- The recipients list, rendered by joining the
+    #:                     recipients list with :attr:`.recipient_join`.
     #: * ``client_name`` -- The hostname of the original message sending
     #:                      client.
     #: * ``client_ip`` -- The IP address of the original message sending
@@ -103,6 +106,11 @@ class Bounce(Envelope):
     #: * ``message`` -- The SMTP reply message that caused the message failure.
     header_template = default_header_template
 
+    #: When bouncing a message that was going to multiple recipients, this
+    #: string is used to join the list of recipients for the ``{recipients}``
+    #: template key.
+    recipient_join = '\r\n- '
+
     #: Template used to add text below the original message data. This template
     #: is processed the same way as ``header_template``.
     footer_template = default_footer_template
@@ -127,19 +135,23 @@ class Bounce(Envelope):
         self.client = Bounce.client
         self.receiver = Bounce.receiver or envelope.receiver
 
-    def _get_substitution_table(self, envelope, reply):
+    def _get_substitution_table(self, envelope, reply, headers_only):
+        rendered_rcpts = self.recipient_join.join(envelope.recipients)
+        ctype = 'text/rfc822-headers' if headers_only else 'message/rfc822'
         return {'boundary': 'boundary_={0}'.format(uuid.uuid4().hex),
                 'sender': envelope.sender,
+                'recipients': rendered_rcpts,
                 'client_name': 'unknown',
                 'client_ip': 'unknown',
                 'dest_host': 'unknown',
                 'dest_port': 'unknown',
                 'protocol': 'SMTP',
+                'content_type': ctype,
                 'code': reply.code,
                 'message': reply.message}
 
     def _build_message(self, envelope, reply, headers_only):
-        sub_table = self._get_substitution_table(envelope, reply)
+        sub_table = self._get_substitution_table(envelope, reply, headers_only)
         new_payload = cStringIO.StringIO()
         new_payload.write(self.header_template.format(**sub_table))
         header_data, message_data = envelope.flatten()
