@@ -30,6 +30,7 @@ from __future__ import absolute_import
 
 import re
 import urlparse
+from socket import getfqdn
 from base64 import b64encode
 
 import gevent
@@ -76,17 +77,18 @@ class HttpRelayClient(RelayPoolClient):
                    (self.relay.ehlo_header, self.relay.ehlo_as),
                    (self.relay.sender_header, b64encode(envelope.sender))]
         for rcpt in envelope.recipients:
-            headers.append((self.relay.rcpt_header, b64encode(rcpt)))
+            headers.append((self.relay.recipient_header, b64encode(rcpt)))
         return headers
 
     def _handle_request(self, result, envelope):
+        method = self.relay.http_verb
         if not self.conn:
             self.conn = get_connection(self.url, self.relay.tls)
         with gevent.Timeout(self.relay.timeout):
             msg_headers, msg_body = envelope.flatten()
             headers = self._build_headers(envelope, msg_headers, msg_body)
-            log.request(self.conn, 'POST', self.url.path, headers)
-            self.conn.putrequest('POST', self.url.path)
+            log.request(self.conn, method, self.url.path, headers)
+            self.conn.putrequest(method, self.url.path)
             for name, value in headers:
                 self.conn.putheader(name, value)
             self.conn.endheaders(msg_headers)
@@ -173,6 +175,9 @@ class HttpRelay(RelayPool):
 
     """
 
+    #: The HTTP verb to use with the requests.
+    http_verb = 'POST'
+
     #: The header name used to send the base64-encoded sender address.
     sender_header = 'X-Envelope-Sender'
 
@@ -187,7 +192,7 @@ class HttpRelay(RelayPool):
         super(HttpRelay, self).__init__(pool_size)
         self.url = url
         self.tls = tls
-        self.ehlo_as = ehlo_as or socket.getfqdn()
+        self.ehlo_as = ehlo_as or getfqdn()
         self.timeout = timeout
         self.idle_timeout = idle_timeout
 
