@@ -32,20 +32,21 @@ import re
 from gevent.ssl import SSLError
 from gevent.socket import timeout as socket_timeout
 from gevent import Timeout
-from gevent.timeout import Timeout as TimeoutHappened
+from pysasl import SASLAuth
 
 from . import SmtpError, ConnectionLost
 from .datareader import DataReader
 from .io import IO
 from .extensions import Extensions
-from .auth import ServerAuthError
+from .auth import ServerAuthError, AuthSession
 from .reply import *
 
 __all__ = ['Server']
 
 from_pattern = re.compile(r'^[fF][rR][oO][mM]:\s*<')
-size_pattern = re.compile(r'\b[sS][iI][zZ][eE]\=(\w+)\b')
 to_pattern = re.compile(r'^[tT][oO]:\s*<')
+param_keyword_pattern = re.compile(r'\b([a-zA-Z0-9][a-zA-Z0-9-]*)')
+param_value_pattern = re.compile(r'\=([\x21-\x3C\x3E-\x7F]+)')
 
 
 def find_outside_quotes(haystack, needle, start_i=0, quotes='"'):
@@ -74,8 +75,11 @@ class Server(object):
     :type socket: :class:`gevent.socket.socket`
     :param handlers: Object with methods that will be called when
                      corresponding SMTP commands are received. These methods
-                     can modify the |Reply| before the command response is sent.
-    :param auth_class: Optional |Auth| sub-class to enable authentication.
+                     can modify the |Reply| before the command response is
+                     sent.
+    :param auth: If True, enable authentication with default mechanisms. May
+                 also be given as a list of SASL mechanism names to support,
+                 e.g. ``['PLAIN', 'LOGIN', 'CRAM-MD5']``.
     :param tls: Optional dictionary of TLS settings passed directly as
                 keyword arguments to :class:`gevent.ssl.SSLSocket`.
     :param tls_immediately: If True, the socket will be encrypted
@@ -92,27 +96,31 @@ class Server(object):
 
     """
 
-    def __init__(self, socket, handlers, auth_class=None,
-                       tls=None, tls_immediately=False, tls_wrapper=None,
-                       command_timeout=None, data_timeout=None):
+    def __init__(self, socket, handlers, auth=False,
+                 tls=None, tls_immediately=False, tls_wrapper=None,
+                 command_timeout=None, data_timeout=None):
         self.handlers = handlers
         self.extensions = Extensions()
 
+        self.io = IO(socket, tls_wrapper)
+
         self.have_mailfrom = None
         self.have_rcptto = None
         self.ehlo_as = None
-        self.auth_result = None
-        self.encrypted = False
+        self.authed = False
 
         self.extensions.add('8BITMIME')
         self.extensions.add('PIPELINING')
         self.extensions.add('ENHANCEDSTATUSCODES')
         if tls and not tls_immediately:
             self.extensions.add('STARTTLS')
-        if auth_class:
-            self.extensions.add('AUTH', auth_class(self))
-
-        self.io = IO(socket, tls_wrapper)
+        if auth:
+            if isinstance(auth, list):
+                auth_obj = SASLAuth(auth)
+            else:
+                auth_obj = SASLAuth()
+            auth_session = AuthSession(auth_obj, self.io)
+            self.extensions.add('AUTH', auth_session)
 
         if tls:
             self.tls = tls.copy()
@@ -124,30 +132,28 @@ class Server(object):
         self.command_timeout = command_timeout
         self.data_timeout = data_timeout or command_timeout
 
+    @property
+    def encrypted(self):
+        """True if the session transport is encrypted, False otherwise."""
+        return self.io.encrypted
+
     def _recv_command(self):
-        timeout = Timeout(self.command_timeout)
-        timeout.start()
-        try:
+        with Timeout(self.command_timeout):
             return self.io.recv_command()
-        finally:
-            timeout.cancel()
 
     def _get_message_data(self):
         max_size = self.extensions.getparam('SIZE', filter=int)
         reader = DataReader(self.io, max_size)
 
         err = None
-        timeout = Timeout(self.data_timeout)
-        timeout.start()
-        try:
-            data = reader.recv()
-        except ConnectionLost:
-            raise
-        except SmtpError as e:
-            data = None
-            err = e
-        finally:
-            timeout.cancel()
+        with Timeout(self.data_timeout):
+            try:
+                data = reader.recv()
+            except ConnectionLost:
+                raise
+            except SmtpError as e:
+                data = None
+                err = e
 
         reply = Reply('250', '2.6.0 Message Accepted for Delivery')
         self._call_custom_handler('HAVE_DATA', reply, data, err)
@@ -162,7 +168,6 @@ class Server(object):
         if not self.io.encrypt_socket(self.tls):
             return False
         self._call_custom_handler('TLSHANDSHAKE')
-        self.encrypted = True
         return True
 
     def _handle_command(self, which, arg):
@@ -191,30 +196,44 @@ class Server(object):
         command, arg = 'BANNER_', None
         while True:
             try:
-                if command:
-                    self._handle_command(command, arg)
-                else:
-                    unknown_command.send(self.io)
-            except StopIteration:
-                break
-            except ConnectionLost:
-                raise
-            except TimeoutHappened:
-                timed_out.send(self.io)
-                self.io.flush_send()
-                break
-            except Exception as e:
-                unhandled_error.send(self.io)
-                raise
-            finally:
-                self.io.flush_send()
+                try:
+                    if command:
+                        self._handle_command(command, arg)
+                    else:
+                        unknown_command.send(self.io)
+                except StopIteration:
+                    break
+                except ConnectionLost:
+                    raise
+                except Exception as e:
+                    unhandled_error.send(self.io)
+                    raise
+                finally:
+                    self.io.flush_send()
 
-            try:
                 command, arg = self._recv_command()
-            except TimeoutHappened:
+            except Timeout:
                 timed_out.send(self.io)
                 self.io.flush_send()
+                raise ConnectionLost()
+
+    def _gather_params(self, remaining):
+        params = {}
+        pos = 0
+        while True:
+            match = param_keyword_pattern.search(remaining, pos)
+            if not match:
                 break
+            param_keyword = match.group(1).upper()
+            pos = match.end(0)
+            value_match = param_value_pattern.match(remaining, pos)
+            if value_match:
+                param_value = value_match.group(1)
+                params[param_keyword] = param_value
+                pos = value_match.end(0)
+            else:
+                params[param_keyword] = True
+        return params
 
     def _command_BANNER_(self, arg):
         reply = Reply('220', 'ESMTP server')
@@ -284,23 +303,26 @@ class Server(object):
         if 'AUTH' not in self.extensions:
             unknown_command.send(self.io)
             return
-        if not self.ehlo_as or self.auth_result or self.have_mailfrom:
+        if not self.ehlo_as or self.authed or self.have_mailfrom:
             bad_sequence.send(self.io)
             return
         auth = self.extensions.getparam('AUTH')
 
-        reply = Reply('235', '2.7.0 Authentication successful')
         try:
-            result = auth.server_attempt(self.io, arg)
+            result = auth.server_attempt(arg)
+        except ValueError:
+            bad_arguments.send(self.io)
+            return
         except ServerAuthError as e:
-            reply.copy(e.reply)
-            result = None
+            e.reply.send(self.io)
+            return
+
+        reply = Reply('235', '2.7.0 Authentication successful')
+        self._call_custom_handler('AUTH', reply, result)
         reply.send(self.io)
 
-        self._call_custom_handler('AUTH', reply, result)
-
         if reply.code == '235':
-            self.auth_result = result
+            self.authed = True
 
     def _command_MAIL(self, arg):
         match = from_pattern.match(arg)
@@ -323,10 +345,11 @@ class Server(object):
             bad_sequence.send(self.io)
             return
 
-        match = size_pattern.search(arg, end+1)
-        if match:
+        params = self._gather_params(arg[end+1:])
+
+        if 'SIZE' in params:
             try:
-                size = int(match.group(1))
+                size = int(params['SIZE'])
             except ValueError:
                 bad_arguments.send(self.io)
                 return
@@ -341,7 +364,7 @@ class Server(object):
                 return
 
         reply = Reply('250', '2.1.0 Sender <{0}> Ok'.format(address))
-        self._call_custom_handler('MAIL', reply, address)
+        self._call_custom_handler('MAIL', reply, address, params)
 
         reply.send(self.io)
 
@@ -364,8 +387,10 @@ class Server(object):
             bad_sequence.send(self.io)
             return
 
+        params = self._gather_params(arg[end+1:])
+
         reply = Reply('250', '2.1.5 Recipient <{0}> Ok'.format(address))
-        self._call_custom_handler('RCPT', reply, address)
+        self._call_custom_handler('RCPT', reply, address, params)
 
         reply.send(self.io)
 
