@@ -1,7 +1,5 @@
 
-import unittest
-
-from assertions import *
+import unittest2 as unittest
 
 
 class TestSlimtaCore(unittest.TestCase):
@@ -11,7 +9,7 @@ class TestSlimtaCore(unittest.TestCase):
 
     def test_import_slimta_core_version(self):
         from slimta.core import __version__
-        self.assert_(isinstance(__version__, basestring))
+        self.assertIsInstance(__version__, basestring)
 
     def test_import_slimta_core_slimtaerror(self):
         from slimta.core import SlimtaError
