@@ -1,6 +1,5 @@
 
-from assertions import *
-
+import unittest2 as unittest
 from mox import MoxTestBase, IsA, IgnoreArg
 import gevent
 from gevent.socket import create_connection
@@ -16,7 +15,7 @@ from slimta.smtp import ConnectionLost, MessageTooBig
 from slimta.smtp.client import Client
 
 
-class TestEdgeSmtp(MoxTestBase):
+class TestEdgeSmtp(unittest.TestCase, MoxTestBase):
 
     def test_call_validator(self):
         mock = self.mox.CreateMockAnything()
@@ -28,13 +27,13 @@ class TestEdgeSmtp(MoxTestBase):
 
     def test_protocol_attribute(self):
         h = SmtpSession(None, None, None)
-        assert_equal('SMTP', h.protocol)
+        self.assertEqual('SMTP', h.protocol)
         h.extended_smtp = True
-        assert_equal('ESMTP', h.protocol)
+        self.assertEqual('ESMTP', h.protocol)
         h.security = 'TLS'
-        assert_equal('ESMTPS', h.protocol)
-        h.auth_result = 'test'
-        assert_equal('ESMTPSA', h.protocol)
+        self.assertEqual('ESMTPS', h.protocol)
+        h.auth = 'test'
+        self.assertEqual('ESMTPSA', h.protocol)
 
     def test_simple_handshake(self):
         mock = self.mox.CreateMockAnything()
@@ -45,26 +44,30 @@ class TestEdgeSmtp(MoxTestBase):
         h = SmtpSession(('127.0.0.1', 0), mock, None)
         h.BANNER_(Reply('220'))
         h.HELO(Reply('250'), 'there')
-        assert_equal('there', h.ehlo_as)
-        assert_false(h.extended_smtp)
+        self.assertEqual('there', h.ehlo_as)
+        self.assertFalse(h.extended_smtp)
 
     def test_extended_handshake(self):
+        creds = self.mox.CreateMockAnything()
+        creds.authcid = 'testuser'
+        creds.authzid = 'testzid'
         mock = self.mox.CreateMockAnything()
         mock.__call__(IsA(SmtpSession)).AndReturn(mock)
         mock.handle_banner(IsA(Reply), ('127.0.0.1', 0))
         mock.handle_ehlo(IsA(Reply), 'there')
         mock.handle_tls()
+        mock.handle_auth(IsA(Reply), creds)
         self.mox.ReplayAll()
         h = SmtpSession(('127.0.0.1', 0), mock, None)
         h.BANNER_(Reply('220'))
         h.EHLO(Reply('250'), 'there')
         h.TLSHANDSHAKE()
-        h.AUTH(Reply('250'), 'testauth')
-        assert_equal('there', h.ehlo_as)
-        assert_true(h.extended_smtp)
-        assert_equal('TLS', h.security)
-        assert_equal('testauth', h.auth_result)
-        assert_equal('ESMTPSA', h.protocol)
+        h.AUTH(Reply('235'), creds)
+        self.assertEqual('there', h.ehlo_as)
+        self.assertTrue(h.extended_smtp)
+        self.assertEqual('TLS', h.security)
+        self.assertEqual('testuser', h.auth)
+        self.assertEqual('ESMTPSA', h.protocol)
 
     def test_mail_rcpt_data_rset(self):
         mock = self.mox.CreateMockAnything()
@@ -76,18 +79,18 @@ class TestEdgeSmtp(MoxTestBase):
         h = SmtpSession(None, mock, None)
         h.MAIL(Reply('250'), 'sender@example.com', {})
         h.RCPT(Reply('250'), 'rcpt@example.com', {})
-        assert_equal('sender@example.com', h.envelope.sender)
-        assert_equal(['rcpt@example.com'], h.envelope.recipients)
+        self.assertEqual('sender@example.com', h.envelope.sender)
+        self.assertEqual(['rcpt@example.com'], h.envelope.recipients)
         h.DATA(Reply('550'))
         h.RSET(Reply('250'))
-        assert_false(h.envelope)
+        self.assertFalse(h.envelope)
 
     def test_have_data_errors(self):
         h = SmtpSession(None, None, None)
         reply = Reply('250')
         h.HAVE_DATA(reply, None, MessageTooBig())
-        assert_equal('552', reply.code)
-        with assert_raises(ValueError):
+        self.assertEqual('552', reply.code)
+        with self.assertRaises(ValueError):
             h.HAVE_DATA(reply, None, ValueError())
 
     def test_have_data(self):
@@ -99,8 +102,8 @@ class TestEdgeSmtp(MoxTestBase):
         h.envelope = env
         reply = Reply('250')
         h.HAVE_DATA(reply, '', None)
-        assert_equal('250', reply.code)
-        assert_equal('2.6.0 Message accepted for delivery', reply.message)
+        self.assertEqual('250', reply.code)
+        self.assertEqual('2.6.0 Message accepted for delivery', reply.message)
 
     def test_have_data_queueerror(self):
         env = Envelope()
@@ -111,8 +114,8 @@ class TestEdgeSmtp(MoxTestBase):
         h.envelope = env
         reply = Reply('250')
         h.HAVE_DATA(reply, '', None)
-        assert_equal('550', reply.code)
-        assert_equal('5.6.0 Error queuing message', reply.message)
+        self.assertEqual('550', reply.code)
+        self.assertEqual('5.6.0 Error queuing message', reply.message)
 
     def test_smtp_edge(self):
         queue = self.mox.CreateMockAnything()
