@@ -1,9 +1,7 @@
 
-import unittest
+import unittest2 as unittest
 import uuid
 
-from assertions import *
-
 from testfixtures import log_capture
 
 from slimta.logging import getQueueStorageLogger
