@@ -1,6 +1,5 @@
 
-from assertions import *
-
+import unittest2 as unittest
 from mox import MoxTestBase, IsA, IgnoreArg
 from gevent.event import AsyncResult
 from gevent import Timeout
@@ -12,15 +11,15 @@ from slimta.relay.http import HttpRelay, HttpRelayClient
 from slimta.http import HTTPConnection
 
 
-class TestHttpRelay(MoxTestBase):
+class TestHttpRelay(unittest.TestCase, MoxTestBase):
 
     def test_add_client(self):
         static = HttpRelay('http://testurl')
         ret = static.add_client()
-        assert_is_instance(ret, HttpRelayClient)
+        self.assertIsInstance(ret, HttpRelayClient)
 
 
-class TestHttpRelayClient(MoxTestBase):
+class TestHttpRelayClient(unittest.TestCase, MoxTestBase):
 
     def setUp(self):
         super(TestHttpRelayClient, self).setUp()
@@ -32,7 +31,7 @@ class TestHttpRelayClient(MoxTestBase):
             tls = None
             http_verb = 'POST'
             sender_header = 'X-Envelope-Sender'
-            rcpt_header = 'X-Envelope-Recipient'
+            recipient_header = 'X-Envelope-Recipient'
             ehlo_header = 'X-Ehlo'
             ehlo_as = 'test'
             timeout = 10.0
@@ -81,15 +80,15 @@ class TestHttpRelayClient(MoxTestBase):
         http_res.getheader('X-Smtp-Reply', '').AndReturn('asdf')
         self.mox.ReplayAll()
         reply1 = self.client._parse_smtp_reply_header(http_res)
-        assert_equal('250', reply1.code)
-        assert_equal('2.0.0 Ok', reply1.message)
-        assert_equal(None, reply1.command)
+        self.assertEqual('250', reply1.code)
+        self.assertEqual('2.0.0 Ok', reply1.message)
+        self.assertEqual(None, reply1.command)
         reply2 = self.client._parse_smtp_reply_header(http_res)
-        assert_equal('550', reply2.code)
-        assert_equal('5.0.0 Nope', reply2.message)
-        assert_equal('smtpcmd', reply2.command)
+        self.assertEqual('550', reply2.code)
+        self.assertEqual('5.0.0 Nope', reply2.message)
+        self.assertEqual('smtpcmd', reply2.command)
         reply3 = self.client._parse_smtp_reply_header(http_res)
-        assert_equal(None, reply3)
+        self.assertEqual(None, reply3)
 
     def test_process_response_200(self):
         http_res = self.mox.CreateMockAnything()
