@@ -1,6 +1,5 @@
 
-from assertions import *
-
+import unittest2 as unittest
 from mox import MoxTestBase, IsA
 import dns.resolver
 from dns.exception import Timeout as DNSTimeout
@@ -39,26 +38,26 @@ class FakeAAnswer(object):
         return iter(self.rdata)
 
 
-class TestMxSmtpRelay(MoxTestBase):
+class TestMxSmtpRelay(unittest.TestCase, MoxTestBase):
 
     def test_get_rcpt_domain(self):
         env = Envelope('sender@example.com', ['rcpt@Example.com'])
         mx = MxSmtpRelay()
-        assert_equal('example.com', mx._get_rcpt_domain(env))
+        self.assertEqual('example.com', mx._get_rcpt_domain(env))
 
     def test_get_rcpt_domain_error(self):
         env = Envelope('sender@example.com', ['badrcpt'])
         mx = MxSmtpRelay()
-        assert_raises(NoDomainError, mx._get_rcpt_domain, env)
+        self.assertRaises(NoDomainError, mx._get_rcpt_domain, env)
 
     def test_choose_mx(self):
         records = [(1, 1), (2, 2), (3, 3), (4, 4), (5, 5)]
         mx = MxSmtpRelay()
-        assert_equal(1, mx.choose_mx(records, 0))
-        assert_equal(5, mx.choose_mx(records, 4))
-        assert_equal(1, mx.choose_mx(records, 5))
-        assert_equal(3, mx.choose_mx(records, 7))
-        assert_equal(2, mx.choose_mx(records, 1821))
+        self.assertEqual(1, mx.choose_mx(records, 0))
+        self.assertEqual(5, mx.choose_mx(records, 4))
+        self.assertEqual(1, mx.choose_mx(records, 5))
+        self.assertEqual(3, mx.choose_mx(records, 7))
+        self.assertEqual(2, mx.choose_mx(records, 1821))
 
     def test_attempt(self):
         env = Envelope('sender@example.com', ['rcpt@example.com'])
@@ -100,7 +99,7 @@ class TestMxSmtpRelay(MoxTestBase):
         dns_resolver.query('example.com', 'MX').AndRaise(dns.resolver.NXDOMAIN)
         dns_resolver.query('example.com', 'A').AndRaise(dns.resolver.NXDOMAIN)
         self.mox.ReplayAll()
-        with assert_raises(PermanentRelayError):
+        with self.assertRaises(PermanentRelayError):
             mx.attempt(env, 0)
 
     def test_attempt_expiredmx(self):
@@ -142,7 +141,7 @@ class TestMxSmtpRelay(MoxTestBase):
         dns_resolver.query('example.com', 'MX').AndRaise(dns.resolver.NoAnswer)
         dns_resolver.query('example.com', 'A').AndRaise(dns.resolver.NoAnswer)
         self.mox.ReplayAll()
-        with assert_raises(PermanentRelayError):
+        with self.assertRaises(PermanentRelayError):
             mx.attempt(env, 0)
 
     def test_attempt_no_answer(self):
@@ -152,7 +151,7 @@ class TestMxSmtpRelay(MoxTestBase):
         self.mox.StubOutWithMock(dns_resolver, 'query')
         dns_resolver.query('example.com', 'MX').AndRaise(DNSTimeout)
         self.mox.ReplayAll()
-        with assert_raises(TransientRelayError):
+        with self.assertRaises(TransientRelayError):
             mx.attempt(env, 0)
 
 
