@@ -1,15 +1,13 @@
 
-from assertions import *
-
+import unittest2 as unittest
 from mox import MoxTestBase, IsA
 from gevent.socket import socket
 
 from slimta.smtp.client import Client, LmtpClient
 from slimta.smtp.reply import Reply
-from slimta.smtp.auth.standard import Plain
 
 
-class TestSmtpClient(MoxTestBase):
+class TestSmtpClient(unittest.TestCase, MoxTestBase):
 
     def setUp(self):
         super(TestSmtpClient, self).setUp()
@@ -22,18 +20,18 @@ class TestSmtpClient(MoxTestBase):
         self.mox.ReplayAll()
         client = Client(self.sock)
         reply = client.get_reply('[TEST]')
-        assert_equal('421', reply.code)
-        assert_equal('4.0.0 Test', reply.message)
-        assert_equal('[TEST]', reply.command)
+        self.assertEqual('421', reply.code)
+        self.assertEqual('4.0.0 Test', reply.message)
+        self.assertEqual('[TEST]', reply.command)
 
     def test_get_banner(self):
         self.sock.recv(IsA(int)).AndReturn('220 Go\r\n')
         self.mox.ReplayAll()
         client = Client(self.sock)
         reply = client.get_banner()
-        assert_equal('220', reply.code)
-        assert_equal('Go', reply.message)
-        assert_equal('[BANNER]', reply.command)
+        self.assertEqual('220', reply.code)
+        self.assertEqual('Go', reply.message)
+        self.assertEqual('[BANNER]', reply.command)
 
     def test_custom_command(self):
         self.sock.sendall('cmd arg\r\n')
@@ -41,9 +39,9 @@ class TestSmtpClient(MoxTestBase):
         self.mox.ReplayAll()
         client = Client(self.sock)
         reply = client.custom_command('cmd', 'arg')
-        assert_equal('250', reply.code)
-        assert_equal('2.0.0 Ok', reply.message)
-        assert_equal('CMD', reply.command)
+        self.assertEqual('250', reply.code)
+        self.assertEqual('2.0.0 Ok', reply.message)
+        self.assertEqual('CMD', reply.command)
 
     def test_ehlo(self):
         self.sock.sendall('EHLO there\r\n')
@@ -52,12 +50,12 @@ class TestSmtpClient(MoxTestBase):
         self.mox.ReplayAll()
         client = Client(self.sock)
         reply = client.ehlo('there')
-        assert_equal('250', reply.code)
-        assert_equal('Hello there', reply.message)
-        assert_equal('EHLO', reply.command)
-        assert_true('TEST' in client.extensions)
-        assert_true('EXTEN' in client.extensions)
-        assert_equal('arg', client.extensions.getparam('TEST'))
+        self.assertEqual('250', reply.code)
+        self.assertEqual('Hello there', reply.message)
+        self.assertEqual('EHLO', reply.command)
+        self.assertTrue('TEST' in client.extensions)
+        self.assertTrue('EXTEN' in client.extensions)
+        self.assertEqual('arg', client.extensions.getparam('TEST'))
 
     def test_helo(self):
         self.sock.sendall('HELO there\r\n')
@@ -65,9 +63,9 @@ class TestSmtpClient(MoxTestBase):
         self.mox.ReplayAll()
         client = Client(self.sock)
         reply = client.helo('there')
-        assert_equal('250', reply.code)
-        assert_equal('Hello', reply.message)
-        assert_equal('HELO', reply.command)
+        self.assertEqual('250', reply.code)
+        self.assertEqual('Hello', reply.message)
+        self.assertEqual('HELO', reply.command)
 
     def test_starttls(self):
         sock = self.mox.CreateMockAnything()
@@ -78,9 +76,9 @@ class TestSmtpClient(MoxTestBase):
         self.mox.ReplayAll()
         client = Client(sock, tls_wrapper=sock.tls_wrapper)
         reply = client.starttls(self.tls_args)
-        assert_equal('220', reply.code)
-        assert_equal('2.0.0 Go ahead', reply.message)
-        assert_equal('STARTTLS', reply.command)
+        self.assertEqual('220', reply.code)
+        self.assertEqual('2.0.0 Go ahead', reply.message)
+        self.assertEqual('STARTTLS', reply.command)
 
     def test_starttls_noencrypt(self):
         self.sock.sendall('STARTTLS\r\n')
@@ -88,9 +86,9 @@ class TestSmtpClient(MoxTestBase):
         self.mox.ReplayAll()
         client = Client(self.sock)
         reply = client.starttls({})
-        assert_equal('420', reply.code)
-        assert_equal('4.0.0 Nope', reply.message)
-        assert_equal('STARTTLS', reply.command)
+        self.assertEqual('420', reply.code)
+        self.assertEqual('4.0.0 Nope', reply.message)
+        self.assertEqual('STARTTLS', reply.command)
 
     def test_auth(self):
         self.sock.sendall('AUTH PLAIN AHRlc3RAZXhhbXBsZS5jb20AYXNkZg==\r\n')
@@ -99,19 +97,19 @@ class TestSmtpClient(MoxTestBase):
         client = Client(self.sock)
         client.extensions.add('AUTH', 'PLAIN')
         reply = client.auth('test@example.com', 'asdf')
-        assert_equal('235', reply.code)
-        assert_equal('2.0.0 Ok', reply.message)
-        assert_equal('AUTH', reply.command)
+        self.assertEqual('235', reply.code)
+        self.assertEqual('2.0.0 Ok', reply.message)
+        self.assertEqual('AUTH', reply.command)
 
     def test_auth_force_mechanism(self):
         self.sock.sendall('AUTH PLAIN AHRlc3RAZXhhbXBsZS5jb20AYXNkZg==\r\n')
         self.sock.recv(IsA(int)).AndReturn('535 Nope!\r\n')
         self.mox.ReplayAll()
         client = Client(self.sock)
-        reply = client.auth('test@example.com', 'asdf', mechanism=Plain)
-        assert_equal('535', reply.code)
-        assert_equal('5.0.0 Nope!', reply.message)
-        assert_equal('AUTH', reply.command)
+        reply = client.auth('test@example.com', 'asdf', mechanism='PLAIN')
+        self.assertEqual('535', reply.code)
+        self.assertEqual('5.0.0 Nope!', reply.message)
+        self.assertEqual('AUTH', reply.command)
 
     def test_mailfrom(self):
         self.sock.sendall('MAIL FROM:<test>\r\n')
@@ -119,9 +117,9 @@ class TestSmtpClient(MoxTestBase):
         self.mox.ReplayAll()
         client = Client(self.sock)
         reply = client.mailfrom('test')
-        assert_equal('250', reply.code)
-        assert_equal('2.0.0 Ok', reply.message)
-        assert_equal('MAIL', reply.command)
+        self.assertEqual('250', reply.code)
+        self.assertEqual('2.0.0 Ok', reply.message)
+        self.assertEqual('MAIL', reply.command)
 
     def test_mailfrom_pipelining(self):
         self.sock.sendall('MAIL FROM:<test>\r\n')
@@ -130,12 +128,12 @@ class TestSmtpClient(MoxTestBase):
         client = Client(self.sock)
         client.extensions.add('PIPELINING')
         reply = client.mailfrom('test')
-        assert_equal(None, reply.code)
-        assert_equal(None, reply.message)
-        assert_equal('MAIL', reply.command)
+        self.assertEqual(None, reply.code)
+        self.assertEqual(None, reply.message)
+        self.assertEqual('MAIL', reply.command)
         client._flush_pipeline()
-        assert_equal('250', reply.code)
-        assert_equal('2.0.0 Ok', reply.message)
+        self.assertEqual('250', reply.code)
+        self.assertEqual('2.0.0 Ok', reply.message)
 
     def test_mailfrom_size(self):
         self.sock.sendall('MAIL FROM:<test> SIZE=10\r\n')
@@ -144,9 +142,9 @@ class TestSmtpClient(MoxTestBase):
         client = Client(self.sock)
         client.extensions.add('SIZE', 100)
         reply = client.mailfrom('test', 10)
-        assert_equal('250', reply.code)
-        assert_equal('2.0.0 Ok', reply.message)
-        assert_equal('MAIL', reply.command)
+        self.assertEqual('250', reply.code)
+        self.assertEqual('2.0.0 Ok', reply.message)
+        self.assertEqual('MAIL', reply.command)
 
     def test_rcptto(self):
         self.sock.sendall('RCPT TO:<test>\r\n')
@@ -154,9 +152,9 @@ class TestSmtpClient(MoxTestBase):
         self.mox.ReplayAll()
         client = Client(self.sock)
         reply = client.rcptto('test')
-        assert_equal('250', reply.code)
-        assert_equal('2.0.0 Ok', reply.message)
-        assert_equal('RCPT', reply.command)
+        self.assertEqual('250', reply.code)
+        self.assertEqual('2.0.0 Ok', reply.message)
+        self.assertEqual('RCPT', reply.command)
 
     def test_rcptto_pipelining(self):
         self.sock.sendall('RCPT TO:<test>\r\n')
@@ -165,12 +163,12 @@ class TestSmtpClient(MoxTestBase):
         client = Client(self.sock)
         client.extensions.add('PIPELINING')
         reply = client.rcptto('test')
-        assert_equal(None, reply.code)
-        assert_equal(None, reply.message)
-        assert_equal('RCPT', reply.command)
+        self.assertEqual(None, reply.code)
+        self.assertEqual(None, reply.message)
+        self.assertEqual('RCPT', reply.command)
         client._flush_pipeline()
-        assert_equal('250', reply.code)
-        assert_equal('2.0.0 Ok', reply.message)
+        self.assertEqual('250', reply.code)
+        self.assertEqual('2.0.0 Ok', reply.message)
 
     def test_data(self):
         self.sock.sendall('DATA\r\n')
@@ -178,9 +176,9 @@ class TestSmtpClient(MoxTestBase):
         self.mox.ReplayAll()
         client = Client(self.sock)
         reply = client.data()
-        assert_equal('354', reply.code)
-        assert_equal('Go ahead', reply.message)
-        assert_equal('DATA', reply.command)
+        self.assertEqual('354', reply.code)
+        self.assertEqual('Go ahead', reply.message)
+        self.assertEqual('DATA', reply.command)
 
     def test_send_empty_data(self):
         self.sock.sendall('.\r\n')
@@ -188,9 +186,9 @@ class TestSmtpClient(MoxTestBase):
         self.mox.ReplayAll()
         client = Client(self.sock)
         reply = client.send_empty_data()
-        assert_equal('250', reply.code)
-        assert_equal('2.0.0 Done', reply.message)
-        assert_equal('[SEND_DATA]', reply.command)
+        self.assertEqual('250', reply.code)
+        self.assertEqual('2.0.0 Done', reply.message)
+        self.assertEqual('[SEND_DATA]', reply.command)
 
     def test_send_data(self):
         self.sock.sendall('One\r\nTwo\r\n..Three\r\n.\r\n')
@@ -198,9 +196,9 @@ class TestSmtpClient(MoxTestBase):
         self.mox.ReplayAll()
         client = Client(self.sock)
         reply = client.send_data('One\r\nTwo\r\n.Three')
-        assert_equal('250', reply.code)
-        assert_equal('2.0.0 Done', reply.message)
-        assert_equal('[SEND_DATA]', reply.command)
+        self.assertEqual('250', reply.code)
+        self.assertEqual('2.0.0 Done', reply.message)
+        self.assertEqual('[SEND_DATA]', reply.command)
 
     def test_rset(self):
         self.sock.sendall('RSET\r\n')
@@ -208,9 +206,9 @@ class TestSmtpClient(MoxTestBase):
         self.mox.ReplayAll()
         client = Client(self.sock)
         reply = client.rset()
-        assert_equal('250', reply.code)
-        assert_equal('2.0.0 Ok', reply.message)
-        assert_equal('RSET', reply.command)
+        self.assertEqual('250', reply.code)
+        self.assertEqual('2.0.0 Ok', reply.message)
+        self.assertEqual('RSET', reply.command)
 
     def test_quit(self):
         self.sock.sendall('QUIT\r\n')
@@ -218,12 +216,12 @@ class TestSmtpClient(MoxTestBase):
         self.mox.ReplayAll()
         client = Client(self.sock)
         reply = client.quit()
-        assert_equal('221', reply.code)
-        assert_equal('2.0.0 Bye', reply.message)
-        assert_equal('QUIT', reply.command)
+        self.assertEqual('221', reply.code)
+        self.assertEqual('2.0.0 Bye', reply.message)
+        self.assertEqual('QUIT', reply.command)
 
 
-class TestLmtpClient(MoxTestBase):
+class TestLmtpClient(unittest.TestCase, MoxTestBase):
 
     def setUp(self):
         super(TestLmtpClient, self).setUp()
@@ -233,11 +231,11 @@ class TestLmtpClient(MoxTestBase):
 
     def test_ehlo_invalid(self):
         client = LmtpClient(self.sock)
-        assert_raises(NotImplementedError, client.ehlo, 'there')
+        self.assertRaises(NotImplementedError, client.ehlo, 'there')
 
     def test_helo_invalid(self):
         client = LmtpClient(self.sock)
-        assert_raises(NotImplementedError, client.helo, 'there')
+        self.assertRaises(NotImplementedError, client.helo, 'there')
 
     def test_lhlo(self):
         self.sock.sendall('LHLO there\r\n')
@@ -246,12 +244,12 @@ class TestLmtpClient(MoxTestBase):
         self.mox.ReplayAll()
         client = LmtpClient(self.sock)
         reply = client.lhlo('there')
-        assert_equal('250', reply.code)
-        assert_equal('Hello there', reply.message)
-        assert_equal('LHLO', reply.command)
-        assert_true('TEST' in client.extensions)
-        assert_true('EXTEN' in client.extensions)
-        assert_equal('arg', client.extensions.getparam('TEST'))
+        self.assertEqual('250', reply.code)
+        self.assertEqual('Hello there', reply.message)
+        self.assertEqual('LHLO', reply.command)
+        self.assertTrue('TEST' in client.extensions)
+        self.assertTrue('EXTEN' in client.extensions)
+        self.assertEqual('arg', client.extensions.getparam('TEST'))
 
     def test_rcptto(self):
         self.sock.sendall('RCPT TO:<test>\r\n')
@@ -259,10 +257,10 @@ class TestLmtpClient(MoxTestBase):
         self.mox.ReplayAll()
         client = LmtpClient(self.sock)
         reply = client.rcptto('test')
-        assert_equal('250', reply.code)
-        assert_equal('2.0.0 Ok', reply.message)
-        assert_equal('RCPT', reply.command)
-        assert_equal([('test', reply)], client.rcpttos)
+        self.assertEqual('250', reply.code)
+        self.assertEqual('2.0.0 Ok', reply.message)
+        self.assertEqual('RCPT', reply.command)
+        self.assertEqual([('test', reply)], client.rcpttos)
 
     def test_rset(self):
         self.sock.sendall('RSET\r\n')
@@ -271,10 +269,10 @@ class TestLmtpClient(MoxTestBase):
         client = LmtpClient(self.sock)
         client.rcpttos = 'testing'
         reply = client.rset()
-        assert_equal('250', reply.code)
-        assert_equal('2.0.0 Ok', reply.message)
-        assert_equal('RSET', reply.command)
-        assert_equal([], client.rcpttos)
+        self.assertEqual('250', reply.code)
+        self.assertEqual('2.0.0 Ok', reply.message)
+        self.assertEqual('RSET', reply.command)
+        self.assertEqual([], client.rcpttos)
 
     def test_send_data(self):
         self.sock.sendall('One\r\nTwo\r\n..Three\r\n.\r\n')
@@ -286,15 +284,15 @@ class TestLmtpClient(MoxTestBase):
                           ('test2', Reply('250')),
                           ('test3', Reply('550'))]
         replies = client.send_data('One\r\nTwo\r\n.Three')
-        assert_equal(2, len(replies))
-        assert_equal('test1', replies[0][0])
-        assert_equal('250', replies[0][1].code)
-        assert_equal('2.0.0 Ok', replies[0][1].message)
-        assert_equal('[SEND_DATA]', replies[0][1].command)
-        assert_equal('test2', replies[1][0])
-        assert_equal('550', replies[1][1].code)
-        assert_equal('5.0.0 Not Ok', replies[1][1].message)
-        assert_equal('[SEND_DATA]', replies[1][1].command)
+        self.assertEqual(2, len(replies))
+        self.assertEqual('test1', replies[0][0])
+        self.assertEqual('250', replies[0][1].code)
+        self.assertEqual('2.0.0 Ok', replies[0][1].message)
+        self.assertEqual('[SEND_DATA]', replies[0][1].command)
+        self.assertEqual('test2', replies[1][0])
+        self.assertEqual('550', replies[1][1].code)
+        self.assertEqual('5.0.0 Not Ok', replies[1][1].message)
+        self.assertEqual('[SEND_DATA]', replies[1][1].command)
 
     def test_send_empty_data(self):
         self.sock.sendall('.\r\n')
@@ -306,15 +304,15 @@ class TestLmtpClient(MoxTestBase):
                           ('test2', Reply('250')),
                           ('test3', Reply('550'))]
         replies = client.send_empty_data()
-        assert_equal(2, len(replies))
-        assert_equal('test1', replies[0][0])
-        assert_equal('250', replies[0][1].code)
-        assert_equal('2.0.0 Ok', replies[0][1].message)
-        assert_equal('[SEND_DATA]', replies[0][1].command)
-        assert_equal('test2', replies[1][0])
-        assert_equal('550', replies[1][1].code)
-        assert_equal('5.0.0 Not Ok', replies[1][1].message)
-        assert_equal('[SEND_DATA]', replies[1][1].command)
+        self.assertEqual(2, len(replies))
+        self.assertEqual('test1', replies[0][0])
+        self.assertEqual('250', replies[0][1].code)
+        self.assertEqual('2.0.0 Ok', replies[0][1].message)
+        self.assertEqual('[SEND_DATA]', replies[0][1].command)
+        self.assertEqual('test2', replies[1][0])
+        self.assertEqual('550', replies[1][1].code)
+        self.assertEqual('5.0.0 Not Ok', replies[1][1].message)
+        self.assertEqual('[SEND_DATA]', replies[1][1].command)
 
 
 # vim:et:fdm=marker:sts=4:sw=4:ts=4
