@@ -1,52 +1,37 @@
 
-from assertions import *
-
+import unittest2 as unittest
 from mox import MoxTestBase, IsA
-from gevent.socket import socket
-from gevent.ssl import SSLError
+from gevent.ssl import SSLSocket, SSLError
+from pysasl import SASLAuth
 
 from slimta.smtp.server import Server
-from slimta.smtp.auth import AuthSession, CredentialsInvalidError
-from slimta.smtp.auth.standard import Plain
+from slimta.smtp.auth import AuthSession
 from slimta.smtp import ConnectionLost
 
 
-class FakeAuth(object):
-
-    def verify_secret(self, cid, secret, zid=None):
-        if cid != 'testuser' or secret != 'testpassword':
-            raise CredentialsInvalidError()
-        if zid is not None and zid != 'testzid':
-            raise CredentialsInvalidError()
-        return (cid, zid)
-
-    def get_available_mechanisms(self, encrypted=False):
-        return [Plain]
-
-
-class TestSmtpServer(MoxTestBase):
+class TestSmtpServer(unittest.TestCase, MoxTestBase):
 
     def setUp(self):
         super(TestSmtpServer, self).setUp()
-        self.sock = self.mox.CreateMock(socket)
+        self.sock = self.mox.CreateMock(SSLSocket)
         self.sock.fileno = lambda: -1
         self.tls_args = {'server_side': True}
 
     def test_starttls_extension(self):
         s = Server(None, None)
-        assert_false('STARTTLS' in s.extensions)
+        self.assertFalse('STARTTLS' in s.extensions)
         s = Server(None, None, tls=self.tls_args, tls_immediately=False)
-        assert_true('STARTTLS' in s.extensions)
+        self.assertTrue('STARTTLS' in s.extensions)
         s = Server(None, None, tls=self.tls_args, tls_immediately=True)
-        assert_false('STARTTLS' in s.extensions)
+        self.assertFalse('STARTTLS' in s.extensions)
 
     def test_recv_command(self):
         self.sock.recv(IsA(int)).AndReturn('cmd ARG\r\n')
         self.mox.ReplayAll()
         s = Server(self.sock, None)
         cmd, arg = s._recv_command()
-        assert_equal('CMD', cmd)
-        assert_equal('ARG', arg)
+        self.assertEqual('CMD', cmd)
+        self.assertEqual('ARG', arg)
 
     def test_get_message_data(self):
         expected_reply = '250 2.6.0 Message Accepted for Delivery\r\n'
@@ -56,15 +41,15 @@ class TestSmtpServer(MoxTestBase):
         self.mox.ReplayAll()
         s = Server(self.sock, None)
         s._get_message_data()
-        assert_false(s.have_mailfrom)
-        assert_false(s.have_rcptto)
+        self.assertFalse(s.have_mailfrom)
+        self.assertFalse(s.have_rcptto)
 
     def test_call_custom_handler(self):
         class TestHandler(object):
             def TEST(self, arg):
                 return arg.lower()
         s = Server(None, TestHandler())
-        assert_equal('stuff', s._call_custom_handler('TEST', 'STUFF'))
+        self.assertEqual('stuff', s._call_custom_handler('TEST', 'STUFF'))
 
     def test_banner_quit(self):
         self.sock.sendall('220 ESMTP server\r\n')
@@ -81,9 +66,9 @@ class TestSmtpServer(MoxTestBase):
         self.sock.sendall('421 4.3.0 Unhandled system error\r\n')
         self.mox.ReplayAll()
         s = Server(self.sock, TestHandler())
-        with assert_raises(Exception) as cm:
+        with self.assertRaises(Exception) as cm:
             s.handle()
-        assert_equal(('test', ), cm.exception.args)
+        self.assertEqual(('test', ), cm.exception.args)
 
     def test_banner_command(self):
         self.sock.sendall('220 ESMTP server\r\n')
@@ -130,7 +115,7 @@ class TestSmtpServer(MoxTestBase):
         s.extensions.reset()
         s.extensions.add('TEST')
         s.handle()
-        assert_equal('there', s.ehlo_as)
+        self.assertEqual('there', s.ehlo_as)
 
     def test_helo(self):
         self.sock.sendall('220 ESMTP server\r\n')
@@ -141,7 +126,7 @@ class TestSmtpServer(MoxTestBase):
         self.mox.ReplayAll()
         s = Server(self.sock, None)
         s.handle()
-        assert_equal('there', s.ehlo_as)
+        self.assertEqual('there', s.ehlo_as)
 
     def test_starttls(self):
         sock = self.mox.CreateMockAnything()
@@ -159,7 +144,7 @@ class TestSmtpServer(MoxTestBase):
         s.extensions.reset()
         s.extensions.add('STARTTLS')
         s.handle()
-        assert_equal(None, s.ehlo_as)
+        self.assertEqual(None, s.ehlo_as)
 
     def test_starttls_bad(self):
         sock = self.mox.CreateMockAnything()
@@ -180,7 +165,7 @@ class TestSmtpServer(MoxTestBase):
         s.extensions.reset()
         s.extensions.add('STARTTLS')
         s.handle()
-        assert_equal('there', s.ehlo_as)
+        self.assertEqual('there', s.ehlo_as)
 
     def test_auth(self):
         self.sock.sendall('220 ESMTP server\r\n')
@@ -193,9 +178,9 @@ class TestSmtpServer(MoxTestBase):
         self.mox.ReplayAll()
         s = Server(self.sock, None)
         s.extensions.reset()
-        s.extensions.add('AUTH', AuthSession(FakeAuth(), s))
+        s.extensions.add('AUTH', AuthSession(SASLAuth(['PLAIN']), s.io))
         s.handle()
-        assert_equal(('testuser', 'testzid'), s.auth_result)
+        self.assertTrue(s.authed)
 
     def test_mailfrom(self):
         self.sock.sendall('220 ESMTP server\r\n')
@@ -208,7 +193,7 @@ class TestSmtpServer(MoxTestBase):
         self.mox.ReplayAll()
         s = Server(self.sock, None)
         s.handle()
-        assert_true(s.have_mailfrom)
+        self.assertTrue(s.have_mailfrom)
 
     def test_mailfrom_bad(self):
         self.sock.sendall('220 ESMTP server\r\n')
@@ -231,7 +216,7 @@ class TestSmtpServer(MoxTestBase):
         self.mox.ReplayAll()
         s = Server(self.sock, None)
         s.handle()
-        assert_true(s.have_mailfrom)
+        self.assertTrue(s.have_mailfrom)
 
     def test_mailfrom_send_extension(self):
         self.sock.sendall('220 ESMTP server\r\n')
@@ -250,7 +235,7 @@ class TestSmtpServer(MoxTestBase):
         s.extensions.reset()
         s.extensions.add('SIZE', 10)
         s.handle()
-        assert_true(s.have_mailfrom)
+        self.assertTrue(s.have_mailfrom)
 
     def test_rcptto(self):
         self.sock.sendall('220 ESMTP server\r\n')
@@ -265,7 +250,7 @@ class TestSmtpServer(MoxTestBase):
         s.ehlo_as = 'test'
         s.have_mailfrom = True
         s.handle()
-        assert_true(s.have_rcptto)
+        self.assertTrue(s.have_rcptto)
 
     def test_rcptto_bad(self):
         self.sock.sendall('220 ESMTP server\r\n')
@@ -286,7 +271,7 @@ class TestSmtpServer(MoxTestBase):
         self.mox.ReplayAll()
         s = Server(self.sock, None)
         s.handle()
-        assert_false(s.have_rcptto)
+        self.assertFalse(s.have_rcptto)
 
     def test_data(self):
         self.sock.sendall('220 ESMTP server\r\n')
@@ -326,7 +311,7 @@ class TestSmtpServer(MoxTestBase):
         s.ehlo_as = 'test'
         s.have_mailfrom = True
         s.have_rcptto = True
-        assert_raises(ConnectionLost, s.handle)
+        self.assertRaises(ConnectionLost, s.handle)
 
     def test_noop(self):
         self.sock.sendall('220 ESMTP server\r\n')
@@ -342,9 +327,9 @@ class TestSmtpServer(MoxTestBase):
         class TestHandlers(object):
             server = None
             def NOOP(self2, reply):
-                assert_equal('test', self2.server.ehlo_as)
-                assert_false(self2.server.have_mailfrom)
-                assert_false(self2.server.have_rcptto)
+                self.assertEqual('test', self2.server.ehlo_as)
+                self.assertFalse(self2.server.have_mailfrom)
+                self.assertFalse(self2.server.have_rcptto)
         self.sock.sendall('220 ESMTP server\r\n')
         self.sock.recv(IsA(int)).AndReturn('RSET arg\r\n')
         self.sock.sendall('501 5.5.4 Syntax error in parameters or arguments\r\n')
@@ -375,7 +360,7 @@ class TestSmtpServer(MoxTestBase):
     def test_custom_command(self):
         class TestHandlers(object):
             def TEST(self2, reply, arg, server):
-                assert_true(server.have_mailfrom)
+                self.assertTrue(server.have_mailfrom)
                 reply.code = '250'
                 reply.message = 'Doing '+arg
         self.sock.sendall('220 ESMTP server\r\n')
@@ -406,10 +391,10 @@ class TestSmtpServer(MoxTestBase):
 
     def test_gather_params(self):
         s = Server(None, None)
-        assert_equal({'ONE': '1'}, s._gather_params(' ONE=1'))
-        assert_equal({'TWO': True}, s._gather_params('TWO'))
-        assert_equal({'THREE': 'foo', 'FOUR': 'bar'}, s._gather_params(' THREE=foo FOUR=bar'))
-        assert_equal({'FIVE': True}, s._gather_params('five'))
+        self.assertEqual({'ONE': '1'}, s._gather_params(' ONE=1'))
+        self.assertEqual({'TWO': True}, s._gather_params('TWO'))
+        self.assertEqual({'THREE': 'foo', 'FOUR': 'bar'}, s._gather_params(' THREE=foo FOUR=bar'))
+        self.assertEqual({'FIVE': True}, s._gather_params('five'))
 
 
 # vim:et:fdm=marker:sts=4:sw=4:ts=4
